


INQUÉRITO CIVIL PÚBLICO N.   ${SIMP}
COMPROMITENTE   ${REQUERIDO}
COMPROMISSÁRIO MINISTÉRIO PÚBLICO DO ESTADO DE MATO GROSSO

TERMO DE AJUSTAMENTO DE CONDUTA

CONSIDERANDO que o Ministério Público é instituição permanente, essencial à função jurisdicional do Estado, incumbindo-lhe a defesa da ordem jurídica, do regime democrático e dos interesses sociais e individuais indisponíveis (CF, art. 127);
CONSIDERANDO que é função institucional do Ministério Público promover o inquérito civil e a ação civil pública, para a proteção do patrimônio público e social, do meio ambiente e de outros interesses difusos e coletivos (CF, art. 129, III);
CONSIDERANDO que, além das funções previstas nas Constituições Federal e Estadual, na Lei Orgânica e em outras leis, incumbe, ainda, ao Ministério Público promover o inquérito civil e a ação civil pública, na forma da lei para a proteção, prevenção e reparação dos danos causados ao meio ambiente, ao consumidor, aos bens e direitos de valor artístico, estético, histórico, turístico e paisagístico, e a outros interesses difusos, coletivos e individuais indisponíveis e homogêneos (Lei Federal n° 8.625/93, art. 25, IV, “a”);
CONSIDERANDO que a responsabilidade civil pela reparação do dano ambiental é objetiva na modalidade de risco integral (art. 2º, § 2º, Lei n. 12.651/2012), sendo a obrigação decorrente do referido dano solidária, imprescritível e propter rem;
CONSIDERANDO que o desmatamento ilegal e as queimadas são a maior causa das emissões brasileiras de gases que contribuem para o aquecimento global e a mudança climática (de consequências ainda imprevisíveis para a economia, a natureza e a sociedade);
CONSIDERANDO que todos têm direito ao meio ambiente ecologicamente equilibrado, bem de uso comum do povo e essencial à sadia qualidade de vida, impondo-se ao Poder Público e à coletividade o dever de defendê-lo e preservá- lo para as presentes e futuras gerações (CF, art. 225);
CONSIDERANDO que a Emenda Constitucional nº 45/2004 indica a necessidade de criação de meios alternativos de solução de conflitos, evitando-se, tanto quanto possível, a propositura de demandas judiciais que, muitas vezes, tramitam por longos períodos e não atingem o êxito pretendido;
CONSIDERANDO que, nos termos da Resolução N. 51/2018 do CSMP/MPMT "na condução de procedimentos instaurados para investigar eventuais ofensas aos direitos da coletividade, o membro do Ministério Público do Estado de Mato Grosso deve promover audiências de conciliação, buscando autocomposição sobre as demandas ou, fundamentar a impossibilidade de adoção da medida";
CONSIDERANDO que, nos termos do art. 6º, §1º, da Resolução 51/2018 do Conselho Superior do Ministério Público do Estado de Mato Grosso, é "...é admissível a destinação dos referidos recursos a projetos de prevenção ou reparação de danos de bens jurídicos da mesma natureza; ao apoio a entidades cuja finalidade institucional inclua a proteção aos direitos ou interesses difusos ou para receber destinação específica que tenha a mesma finalidade dos fundos previstos em lei ou esteja em conformidade com a natureza e a dimensão do dano";
O MINISTÉRIO PÚBLICO DO ESTADO DE MATO GROSSO, por seu Promotor de Justiça signatário, no uso de suas atribuições constitucionais, com fundamento no art. 5º, § 6º, da Lei Federal n° 7.347/85 e nos arts. 9-A da Lei Federal n° 6.938/81, doravante denominado COMPROMISSÁRIO, e de outro lado, como COMPROMITENTE:
  ${REQUERIDO}, brasileiro, casado, produtor rural, inscrito no CPF nº ___.___.___-__, RG nº         , residente na   ${ENDEREÇO}, telefone                ;

celebram o presente TERMO DE AJUSTAMENTO DE CONDUTA na melhor forma de direito, a fim de adotar medidas visando à compensação do dano ambiental e evitar-se a judicialização do conflito com a deflagração de Ação Civil Pública.
DO HISTÓRICO
O Inquérito Civil Público N.   ${SIMP}, fora instaurado a partir do              , na   ${PROPRIEDADE}, de propriedade do requerido   ${COMPROMITENTE}, inscrito no CPF nº, RG nº, residente na   ${ENDEREÇO}, referente aos anos de, e cuja responsabilidade civil, em tese, recai sobre o proprietário do imóvel,   ${REQUERIDO}, ora COMPROMITENTE.
DO MÉTODO. Para fins de reparação do dano ambiental decorrente de desflorestamento ilegal, adotou-se como o critério para reparação do dano ambiental pela estimativa dos custos totais de reparação dano ambiental, baseando-se em estudos de Timotheo, Santana e Benini (2017);
DO OBJETO: Tem o presente termo de compromisso como objeto a OBRIGAÇÃO DE FAZER consistente em instituir servidão ambiental perpétua sobre a área de desmatamento ilegal localizada no imóvel de propriedade do COMPROMITENTE, abaixo descrita, para fins de reparação do dano ambiental “in natura” e “in situ” decorrente da supressão ilegal de vegetação nativa segundo as cláusulas e cominações adiante estabelecidas.
O COMPROMITENTE declara ser proprietário do imóvel rural matriculado sob o n° _____, do 1° Registro de Imóveis de Itiquira/MT, que foi havido pelo compromitente por força do registro n° ___, da citada matrícula.
DA ÁREA DA SERVIDÃO AMBIENTAL. O COMPROMITENTE, como forma de composição civil do dano ambiental, livre de qualquer coação ou constrangimento, espontaneamente opta por reparar o dano ambiental acima descrito e apurado no âmbito deste inquérito civil, referente à supressão não autorizada de vegetação nativa ocorrida nas proximidades das coordenadas e data supra descritas (item "HISTÓRICO") por meio da instituição, na referida área, de servidão ambiental prevista no artigos 9º, XIII, e 9-A da Lei Federal n° 6.938/81, sobre a área de supressão vegetal não autorizada apurada no presente Inquérito Civil   ${SIMP}, na referida área, conforme Relatório Técnico _______, totalizando _____hectares devendo para tanto:
apresentar memorial descritivo da área da servidão ambiental, contendo pelo menos um ponto de amarração georreferenciado (9-A, §1º, I, da Lei Federal n° 6.938/81), no prazo de 60 (sessenta) dias contados da homologação deste termo de ajustamento de conduta;
Os mapas e memorial descritivo deverão estar acompanhados de Anotação de Responsabilidade Técnica (ART) por profissional devidamente credenciado a realizar o referido trabalho;
O profissional contratado deverá declarar que a área do memorial descritivo corresponde integralmente à área de supressão vegetal não autorizada apurada no presente inquérito civil, devendo estar ciente das cominações previstas no art. 69-A da Lei 9.605/98;
Na hipótese de ser constatado que a supressão ilegal de vegetação nativa ocorreu em área legalmente protegida (área de preservação permanente ou área de reserva legal), o COMPROMITENTE deverá indicar outra área da referida propriedade, lindeira à ARL ou APP existente, para fins de estabelecimento da servidão ambiental.
De posse dos documentos mencionados na cláusula anterior, o COMPROMITENTE deverá lavrar instrumento público ou particular, conforme o disposto no artigo 9-A, caput, da Lei Federal n° 6.938/81, e averbá-lo perante o Cartório de Imóveis competente para adimplir a presente obrigação de fazer consistente em instituir SERVIDÃO AMBIENTAL conforme os itens a seguir definidos.
O instrumento que institui a servidão ambiental nos termos definidos neste compromisso deverá ser averbado no Cartório de Imóveis no prazo máximo de 120 dias a partir da assinatura do presente termo de ajustamento de conduta.
Antes de lavrar o instrumento em questão, o COMPROMITENTE deverá apresentar o memorial descritivo ao COMPROMISSÁRIO para obter deste a anuência quanto ao polígono da área delimitada, sendo que, o tempo gasto pelo COMPROMISSÁRIO para se manifestar não será levado em consideração para fins de descumprimento dos prazos do presente compromisso.
DO PRAZO DA SERVIDÃO AMBIENTAL. A instituição da servidão ambiental será feita de forma permanente  (9-A, §1º, IV, da Lei Federal n° 6.938/81), impossibilitando o seu cancelamento ou revogação, obrigando a todos os sucessores ao seu fiel cumprimento. 
Será vedada a alteração da destinação da área, nos casos de transmissão a qualquer título, de desmembramento ou de retificação dos limites da propriedade. 
O presente compromisso obrigará as partes que o celebrarem, herdeiros e sucessores, a quem o COMPROMITENTE deverá dar publicidade.
O COMPROMITENTE renuncia voluntariamente, em caráter permanente e irrevogável, a direitos de supressão ou exploração madeireira da vegetação nativa, e se compromete a limitar o uso e preservar os recursos ambientais existentes na área em que será instituída a servidão ambiental objeto deste termo, a qual não poderá ser dada outra destinação, conforme a seguir definido.
DA RESTRIÇÃO AO USO. A restrição ao uso ou à exploração da vegetação da área sob servidão ambiental será, no mínimo, a estabelecida para a Reserva Legal (cf. art. 9º-A, § 3º da Lei 6.938/81), com as seguintes alterações:
É vedada a exploração florestal madeireira, tendo em vista a necessidade de fixação de carbono;
É vedado o cultivo de espécies exóticas à fauna e à flora brasileira e ao respectivo bioma na área de servidão ambiental;
DOS DIREITOS. O proprietário ou possuidor terá, portanto, os direitos:
de propriedade;
pesquisa científica e a visitação com objetivos turísticos, recreativos e educacionais;
a exploração extrativista de frutos, castanhas e sementes da flora nativa mediante plano de manejo aprovado pelo órgão ambiental, aplicando-se, no que couber, o disposto no art. 23, §2º, da Lei 9.985/2000;
o enriquecimento e aceleramento da recuperação da área mediante o plantio de espécies nativas com potencial extrativista não-madeireiro;
após o prazo de 15 (quinze) anos, destinados à exclusiva prestação de serviços ecossistêmicos pela servidão ambiental em questão, o proprietário poderá, caso queira e preenchidos os requisitos legais, comercializar cota de reserva ambiental de que trata o art. 15, §2º, da Lei 12.651/2012 ou utilizar a referida área para fins de compensação de reserva legal de outras propriedades;
"A servidão ambiental perpétua equivale, para fins creditícios, tributários e de acesso aos recursos de fundos públicos, à Reserva Particular do Patrimônio Natural - RPPN" (art. 9º-B, §2º, da Lei 6.938/81)
DOS DEVERES. O proprietário ou possuidor terá os deveres de:
manter o isolamento da área, principalmente do acesso ao gado, inclusive com o uso de cerca onde se fizer necessário;
observar as regras de uso sustentável próprias da Reserva Legal, com as alterações acima constantes;
permitir acesso à área de servidão ambiental a instituição pública brasileira sem fins lucrativos, incumbida regimental ou estatutariamente da pesquisa (dentre elas, a Universidade Federal de Rondonópolis);
O compromitente deverá afixar uma placa do tamanho de um outdoor (tamanho mínimo de 2m por 6 metros) identificando a área de servidão ambiental. A arte e as especificações da referida placa/outdoor deverão ser solicitadas e encaminhadas pelo e-mail da respectiva Promotoria de Justiça.
Os custos decorrentes da lavratura e registro do instrumento de instituição de servidão ambiental (art. 9º-A, § 1º, da Lei n. 6.938/1981) correrão por conta do COMPROMITENTE.
O Ministério Público fiscalizará a regeneração natural da vegetação nativa por sistema automatizado de alertas GLAD, configurados conforme o polígono do imóvel em questão (“cerca eletrônica”).
O COMPROMITENTE está ciente do crime previsto no art. 48 da Lei 6.508/98, segundo o qual “Impedir ou dificultar a regeneração natural de florestas e demais formas de vegetação: Pena - detenção, de seis meses a um ano, e multa”.
O COMPROMITENTE declara que não promoverá supressão ilegal de vegetação (desmatamento ilegal) no imóvel em questão e a realização de novos atos de desmatamento ilegal (isto é, não autorizado pelo órgão ambiental competente) caracterizará o descumprimento do presente termo de ajustamento de conduta, por importar em novas violações ao bem jurídico por ele protegido.
A limitação das obrigações de reparação do dano ambiental do COMPROMITENTE ao isolamento da área e instituição da servidão ambiental dependerá da efetiva resiliência do ecossistema abalado em promover a regeneração natural da área e o  MINISTÉRIO PÚBLICO DO ESTADO DE MATO GROSSO poderá exigir do COMPROMITENTE a apresentação de laudo de constatação de regeneração natural para comprovação da regeneração natural, obrigando-se o COMPROMITENTE a apresentá-lo no prazo de 60 (sessenta dias) após a notificação do MINISTÉRIO PÚBLICO DO ESTADO DE MATO GROSSO. 
Caso, no prazo de dois anos após a homologação deste, não se verifique a possibilidade de regeneração natural da área, o compromitente obriga-se à apresentação e execução de Projeto de Recomposição de Áreas Degradadas e Alteradas (PRADA) acompanhado de Anotação de Responsabilidade Técnica (ART).
Os COMPROMITENTES concordam em sujeitar a área objeto da servidão ambiental a atos de restauração por iniciativa do Poder Público, da sociedade civil, nos termos do art. 1º-A, parágrafo único, IV, do Novo Código Florestal (“Tendo como objetivo o desenvolvimento sustentável, esta Lei atenderá aos seguintes princípios: responsabilidade comum da União, Estados, Distrito Federal e Municípios, em colaboração com a sociedade civil, na criação de políticas para a preservação e restauração da vegetação nativa e de suas funções ecológicas e sociais nas áreas urbanas e rurais”) para realizar atividades de restauração da floresta nativa, inclusive mediante a dispersão de sementes por lançamento manual, aéreo ou outro método (drones) no âmbito de projetos de pesquisa científica.
As obrigações ora assumidas com o MINISTÉRIO PÚBLICO DO ESTADO DE MATO GROSSO para fins de reparação do dano ambiental não impedem que outras exigências sejam feitas pelo órgão ambiental competente na esfera administrativa, nem isentam o proprietário da regularização ambiental perante o órgão de fiscalização ambiental, nos termos da legislação vigente.
DA CONVERSÃO PARCIAL DOS VALORES "IN PECUNIA" EM REPARAÇÃO DO DANO "IN NATURA" (SERVIDÃO AMBIENTAL PERPÉTUA). Oportuniza-se ao COMPROMITENTE a conversão em servidão ambiental de 70% do valor "in pecunia" correspondente à indenização do valor correspondente à reparação do dano extrapatrimonial “in natura”, conforme demonstrativo de cálculo de valoração do dano ambiental em anexo, que passa a fazer parte integrante do presente termo, chegando-se à seguinte conversão e parcela “in pecunia” residual:
__ hectares (área de servidão a ser acrescida em razão da conversão)
R$ ____ (parcela mínima "in pecunia" a título de reparação de danos extrapatrimoniais);
DA REPARAÇÃO DO DANO AMBIENTAL "IN PECUNIA". A título de reparação civil do dano extrapatrimonial, considerando-se, ainda, que o dano ambiental causado é rigorosamente irreparável, o COMPROMITENTE assume a obrigação de fazer consistente no auxílio ao custeio de projeto ambiental, mediante doação da importância de R$ 15.351,56, valor este que poderá ser dividido em até 10 vezes, ao seguinte projeto: "Programa de Recuperação de áreas degradadas no Sudeste de Mato Grosso: capacitação tecnológica e regularização ambiental de áreas públicas e privadas (PRORAD)" (Protocolo: 211120181713271930 do Sistema de Extensão da UFMT/UFR), voltado à promoção da restauração ecológica no município de Itiquira, projeto este de autoria da UNIVERSIDADE FEDERAL DE RONDONÓPOLIS, instituição pública brasileira sem fins lucrativos, que possui inquestionável reputação ético-profissional, e incumbida regimental e estatutariamente da pesquisa. O início do cumprimento deverá dar-se em 60 dias a partir da celebração deste. 
FORMA DE PAGAMENTO: Depósito ou transferência bancária na conta bancária: BANCO DO BRASIL, Agência: 8687-8, Conta corrente: 82.110-1, FUNDAÇÃO UNISELVA PRORAD, CNPJ: 04.845.150/0001-57, específica do referido projeto (Protocolo: 211120181713271930 do Sistema de Extensão da UFMT/UFR).
O adimplemento desta obrigação deverá se dar com a apresentação dos recibos de depósito ou transferência bancária.
O MINISTÉRIO PÚBLICO DO ESTADO DE MATO GROSSO compromete-se a promover o arquivamento do presente Inquérito Civil Público, em relação a este fato enquanto houver o cumprimento das cláusulas acima, ressalvado o surgimento de fato novo omitido pelo COMPROMITENTE referente ao objeto acordado ou novas evidências de lesão à área em questão;
O presente TERMO DE AJUSTAMENTO DE CONDUTA é título executivo extrajudicial, nos termos do art. 5º, § 6º, da Lei nº 7.347/85. 
DO INÍCIO DA EFICÁCIA. A eficácia do presente TERMO DE AJUSTAMENTO DE CONDUTA inicia-se na data de sua celebração.
DA MULTA COMINATÓRIA - Em caso de descumprimento, pelo COMPROMITENTE, de quaisquer das obrigações assumidas neste COMPROMISSO, incidirá multa mensal, no montante de R$ 5.000,00 (cinco mil reais), conforme art. 5º, § 6º, da Lei nº 7.347/1985, a ser ressarcida ao Fundo Estadual de Reparação de Direitos Difusos e Coletivos, consoante prevê o artigo 13 da Lei 7.347/85, a ser paga independentemente da ação executiva da obrigação de fazer, sem prejuízo de outras medidas legais.
Na eventualidade de não haver o adimplemento da referida multa cominatória, o seu montante será atualizado pelo IGP-M/FGV, sem prejuízo, ainda, de juros de mora de 6% (seis por cento) ao ano, a contar do descumprimento das obrigações assumidas nas cláusulas anteriores.
Na hipótese de descumprimento da obrigação de fazer, consistente em efetivar a instituição (mediante memorial descritivo) e registrar a servidão ambiental nos termos estabelecidos no presente termo de ajustamento de conduta, o MINISTÉRIO PÚBLICO DO ESTADO DE MATO GROSSO promoverá ação visando o suprimento da vontade do COMPROMITENTE, com a averbação da servidão ambiental com base em memorial descritivo apresentado pelo próprio MINISTÉRIO PÚBLICO DO ESTADO DE MATO GROSSO, sem prejuízo da cobrança de multa e, ainda, apuração integral da reparação do dano ambiental segundo um dos métodos científicos de valoração do dano ambiental (Custos Ambientais Totais Esperados - CATE ou Valor de Compensação Ambiental - VCP) definidos na obra técnica Valoração do Dano Ambiental: Casos Aplicados ao Estado de Mato Grosso.
As cláusulas acima estipuladas são consideradas obrigações de relevante interesse ambiental para fins do art. 68 da Lei 9.605/98 ("Art. 68. Deixar, aquele que tiver o dever legal ou contratual de fazê-lo, de cumprir obrigação de relevante interesse ambiental");
DO FORO COMPETENTE - Fica eleito o foro da Comarca de Itiquira para a solução de eventuais litígios decorrentes da execução do presente COMPROMISSO.
Poderá ser celebrado aditivo ao presente termo, desde que imprevistos técnicos o exijam. 
Por estarem de acordo, firmam o presente TERMO DE AJUSTAMENTO DE CONDUTA, sendo que a efetivação do referido arquivamento dependerá de homologação do Egrégio Conselho Superior do MINISTÉRIO PÚBLICO DO ESTADO DE MATO GROSSO, em cumprimento ao disposto no artigo 9º, § 3°, da Lei n° 7.347/1985, e na Resolução N. 51/2018, expedida pelo Conselho Superior do MINISTÉRIO PÚBLICO DO ESTADO DE MATO GROSSO.
Estando assim ajustadas suas condutas, após lido e achado conforme, assinam o membro do MINISTÉRIO PÚBLICO DO ESTADO DE MATO GROSSO, o compromitente   ${REQUERIDO}, em duas vias, de igual teor.

${CIDADE}, ${data_hoje}
 
${CIDADE}, ${DATA_HOJE}


${SUBSCRITOR}
${CARGO_SUBSCRITOR}

 
${REQUERIDO}
COMPROMITENTE
